@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Array.pm
-## Version v2.0.0
+## Version v2.0.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2022/11/30
+## Modified 2023/09/07
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -34,7 +34,7 @@ BEGIN
     use constant BREAK_LOOP => \"BREAK";
     $DEBUG  = 0;
     $RETURN = {};
-    our $VERSION = 'v2.0.0';
+    our $VERSION = 'v2.0.1';
 };
 
 use strict;
@@ -79,7 +79,7 @@ sub as_hash
     my $self = CORE::shift( @_ );
     my $opts = {};
     $opts = CORE::shift( @_ ) if( ( Scalar::Util::reftype( $opts ) // '' ) eq 'HASH' );
-    my $ref = {};
+    # my $ref = {};
     my $offsets = $self->keys;
     if( $opts->{start_from} )
     {
@@ -89,9 +89,12 @@ sub as_hash
             $offsets->[ $i ] += $start;
         }
     }
-    @$ref{ @$self } = @$offsets;
     require Module::Generic::Hash;
-    CORE::return( Module::Generic::Hash->new( $ref ) );
+    # Since our array might contain reference, we instantiate first our special hash object, and then we add into it our elements
+    # Module::Generic::Hash, that uses Module::Generic::TieHash, knows how to handle keys as reference
+    my $ref = Module::Generic::Hash->new;
+    @$ref{ @$self } = @$offsets;
+    return( $ref );
 }
 
 sub as_string
@@ -351,10 +354,13 @@ sub foreach
     my $self = CORE::shift( @_ );
     my $code = CORE::shift( @_ );
     CORE::return if( ref( $code ) ne 'CODE' );
-    CORE::foreach my $v ( @$self )
+    # CORE::foreach my $v ( @$self )
+    CORE::foreach( @$self )
     {
-        local $_ = $v;
-        my $rv = $code->( $v );
+        # local $_;
+        # local $_ = $v;
+        # my $rv = $code->( $v );
+        my $rv = $code->( $_ );
         CORE::last if( CORE::defined( $rv ) && CORE::length( "$rv" ) && ( $rv eq BREAK_LOOP || !$rv ) );
         if( CORE::defined( my $ret = $self->return ) )
         {
